@@ -12,6 +12,7 @@
 
 namespace Composer\ClassMapGenerator;
 
+use RuntimeException;
 use Composer\Pcre\Preg;
 
 /**
@@ -23,13 +24,17 @@ class PhpFileParser
      * Extract the classes in the given file
      *
      * @param  string            $path The file to check
-     * @throws \RuntimeException
-     * @return array<int, class-string> The found classes
+     * @throws RuntimeException
+     * @return list<class-string> The found classes
      */
     public static function findClasses(string $path): array
     {
         $extraTypes = self::getExtraTypes();
 
+        if (!function_exists('php_strip_whitespace')) {
+            throw new RuntimeException('Classmap generation relies on the php_strip_whitespace function, but it has been disabled by the disable_functions directive.');
+        }
+
         // Use @ here instead of Silencer to actively suppress 'unhelpful' output
         // @link https://github.com/composer/composer/pull/4886
         $contents = @php_strip_whitespace($path);
@@ -40,21 +45,23 @@ class PhpFileParser
                 $message = 'File at "%s" is not readable, check its permissions';
             } elseif ('' === trim((string) file_get_contents($path))) {
                 // The input file was really empty and thus contains no classes
-                return array();
+                return [];
             } else {
                 $message = 'File at "%s" could not be parsed as PHP, it may be binary or corrupted';
             }
+
             $error = error_get_last();
             if (isset($error['message'])) {
                 $message .= PHP_EOL . 'The following message may be helpful:' . PHP_EOL . $error['message'];
             }
-            throw new \RuntimeException(sprintf($message, $path));
+
+            throw new RuntimeException(sprintf($message, $path));
         }
 
         // return early if there is no chance of matching anything in this file
         Preg::matchAllStrictGroups('{\b(?:class|interface|trait'.$extraTypes.')\s}i', $contents, $matches);
-        if (0 === \count($matches)) {
-            return array();
+        if ([] === $matches[0]) {
+            return [];
         }
 
         $p = new PhpFileCleaner($contents, count($matches[0]));
@@ -63,27 +70,31 @@ class PhpFileParser
 
         Preg::matchAll('{
             (?:
-                 \b(?<![\$:>])(?P<type>class|interface|trait'.$extraTypes.') \s++ (?P<name>[a-zA-Z_\x7f-\xff:][a-zA-Z0-9_\x7f-\xff:\-]*+)
-               | \b(?<![\$:>])(?P<ns>namespace) (?P<nsname>\s++[a-zA-Z_\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*+(?:\s*+\\\\\s*+[a-zA-Z_\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*+)*+)? \s*+ [\{;]
+                 \b(?<![\\\\$:>])(?P<type>class|interface|trait'.$extraTypes.') \s++ (?P<name>[a-zA-Z_\x7f-\xff:][a-zA-Z0-9_\x7f-\xff:\-]*+)
+               | \b(?<![\\\\$:>])(?P<ns>namespace) (?P<nsname>\s++[a-zA-Z_\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*+(?:\s*+\\\\\s*+[a-zA-Z_\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*+)*+)? \s*+ [\{;]
             )
         }ix', $contents, $matches);
 
-        $classes = array();
+        $classes = [];
         $namespace = '';
 
-        for ($i = 0, $len = count($matches['type']); $i < $len; $i++) {
+        for ($i = 0, $len = count($matches['type']); $i < $len; ++$i) {
             if (isset($matches['ns'][$i]) && $matches['ns'][$i] !== '') {
-                $namespace = str_replace(array(' ', "\t", "\r", "\n"), '', (string) $matches['nsname'][$i]) . '\\';
+                $namespace = str_replace([' ', "\t", "\r", "\n"], '', (string) $matches['nsname'][$i]) . '\\';
             } else {
                 $name = $matches['name'][$i];
                 assert(is_string($name));
                 // skip anon classes extending/implementing
-                if ($name === 'extends' || $name === 'implements') {
+                if ($name === 'extends') {
                     continue;
                 }
+                if ($name === 'implements') {
+                    continue;
+                }
+
                 if ($name[0] === ':') {
                     // This is an XHP class, https://github.com/facebook/xhp
-                    $name = 'xhp'.substr(str_replace(array('-', ':'), array('_', '__'), $name), 1);
+                    $name = 'xhp'.substr(str_replace(['-', ':'], ['_', '__'], $name), 1);
                 } elseif (strtolower((string) $matches['type'][$i]) === 'enum') {
                     // something like:
                     //   enum Foo: int { HERP = '123'; }
@@ -98,27 +109,29 @@ class PhpFileParser
                         $name = substr($name, 0, $colonPos);
                     }
                 }
-                $classes[] = ltrim($namespace . $name, '\\');
+
+                /** @var class-string */
+                $className = ltrim($namespace . $name, '\\');
+                $classes[] = $className;
             }
         }
 
         return $classes;
     }
 
-    /**
-     * @return string
-     */
     private static function getExtraTypes(): string
     {
         static $extraTypes = null;
 
         if (null === $extraTypes) {
             $extraTypes = '';
+            $extraTypesArray = [];
             if (PHP_VERSION_ID >= 80100 || (defined('HHVM_VERSION') && version_compare(HHVM_VERSION, '3.3', '>='))) {
                 $extraTypes .= '|enum';
+                $extraTypesArray = ['enum'];
             }
 
-            PhpFileCleaner::setTypeConfig(array_merge(['class', 'interface', 'trait'], array_filter(explode('|', $extraTypes))));
+            PhpFileCleaner::setTypeConfig(array_merge(['class', 'interface', 'trait'], $extraTypesArray));
         }
 
         return $extraTypes;
@@ -132,7 +145,6 @@ class PhpFileParser
      *
      * @see Composer\Util\Filesystem::isReadable
      *
-     * @param  string $path
      * @return bool
      */
     private static function isReadable(string $path)
